@@ -71,7 +71,7 @@ DICOMImage::DICOMImage(const char *path, bool verbose, bool haveNumSlices) :
 	error_(false),
 	handle_(NULL),
 	imageNum_(0),
-	numGroups_(1),
+	numGroups_(0),
 	mosaic_(false),
 	d3_(false),
 	sliceThickness_(0.0),
@@ -109,6 +109,7 @@ DICOMImage::DICOMImage(const char *path, bool verbose, bool haveNumSlices) :
 			&& GetImageNumber()
 			&& GetACQNumber()
 			&& GetACQEchoNumber()
+			&& GetACQMatrix()
 			&& GetD3()
 			&& GetSliceThickness()
 			&& (haveNumSlices || GetNumSlices())
@@ -124,7 +125,7 @@ DICOMImage::DICOMImage(const char *path, bool verbose, bool haveNumSlices) :
 			&& GetPhaseEncoding()
 			&& GetImgRescaleIntercept()
 			&& GetImgRescaleSlope()
-			&& GetNumGroups()
+			&& GetGroupsInfo()
 			&& GetSeriesDescription()
 			&& GetSeriesNumber()
 			&& GetSeriesID()
@@ -902,6 +903,44 @@ bool DICOMImage::GetACQEchoNumber()
    return true;
 }
 
+//////////////////////////////////////////////////////////////////////////////
+///
+/// Purpose: Get the value for the acquisition matrix (0018, 1310)
+///   
+/// @param   NONE 
+///   
+/// @return  false if error
+///   
+/// Notes: 
+///
+//////////////////////////////////////////////////////////////////////////////
+
+bool DICOMImage::GetACQMatrix()
+{
+   U16 values[4] = {0,0,0,0};	
+   if (GetData(DCM_ACQACQUISITIONMATRIX, values) == 0)
+   {
+	  error_ = false;
+	  COND_PopCondition(TRUE);				// Clear error from stack
+   }
+
+   // Values are Phase Columns/Phase Rows/Frequency Column/Frequency Row
+   // two will always be 0, the other two will give the accurate count
+
+   if ( values[0] == 0 )
+   {
+	   acqRows_ = values[1];
+	   acqColumns_ = values[2];
+   }
+   else
+   {
+	   acqColumns_ = values[0];
+	   acqRows_ = values[3];
+   }
+   
+   return true;
+}
+
 //////////////////////////////////////////////////////////////////////////////
 ///
 /// Purpose: Get the value for the image orientation (0020, 0037)
@@ -1309,7 +1348,8 @@ char *DICOMImage::GetShadowSet()
 //////////////////////////////////////////////////////////////////////////////
 ///
 /// Purpose: Read the Siemens special data (0029, 1020) and get the number of
-///          groups in this directory.
+///          groups in this directory plus each group's size and starting
+///          image number.
 ///   
 /// @param   
 ///   
@@ -1320,40 +1360,71 @@ char *DICOMImage::GetShadowSet()
 ///
 //////////////////////////////////////////////////////////////////////////////
 
-bool DICOMImage::GetNumGroups()
+bool DICOMImage::GetGroupsInfo()
 {
 	char *storage = GetShadowSet();
 
 	if ( (manufacturer_ != SIEMENS) || (storage == NULL) )
 	{
 		numGroups_ = 1;
+		groupSize_.resize(1);
+		groupSize_[0] = 1;
+		groupStartImage_.resize(1);
+		groupStartImage_[0] = 1;
 		return true;
 	}
 
 	bool found = false;
-	  
+
 	// Find all of the info of the form "sGroupArray.asGroup[nn].nSize" and
 	// store the last "nn" value found.
   
 	char *tok = strtok(storage, "\n");
 	while ( tok )
 	{
+		// Make sure we don't go past the end
+		if ((*tok == '#') && (strncmp(tok, "### ASCCONV END ###", 18) == 0))
+			break;
+		
 		if ( ! strncmp(tok, "sGroupArray.asGroup[", 20) )
 		{
 			char *valuep = strstr(tok, "[");
-			sscanf(valuep, "[%i].", &numGroups_);
+			int groupNum;
+			sscanf(valuep, "[%i].", &groupNum);
+			if ( groupNum >= numGroups_ )
+			{
+				numGroups_ = groupNum + 1;                // The indexes start at 0, we want the total #
+				if ( groupSize_.size() < numGroups_ )
+				{
+					groupSize_.resize(numGroups_);
+					groupStartImage_.resize(numGroups_);
+				}
+			}
+			
+			valuep = strstr(tok, "= ");
+			int parValue;
+			sscanf(valuep, "= %d", &parValue);
+			char *parp = strstr(tok, "]");
+			if ( ! strncmp(parp, "].nSize", 7) )
+			{
+				groupSize_[groupNum] = parValue;
+			}
+			else if ( ! strncmp(parp, "].nLow", 6) )
+			{
+				// What is stored is the last image number of th previous group
+				
+				groupStartImage_[groupNum] = parValue + 1; 
+			}
+			
 			found = true;
 		}
-		else
-			if ( found )
-				break;
 		  
 		tok = strtok(NULL, "\n");
 	}
 
 	if ( ! found )
 	{
-		string msg("DICOMImage::NumGroups: Cannot get value of Siemens info in image ");
+		string msg("DICOMImage::GetGroupsInfo: Cannot get value of Siemens info in image ");
 		msg += imgPath_;
 		cerr << endl << "\t**** " << msg << endl;
 		error_ = true;
@@ -1362,7 +1433,10 @@ bool DICOMImage::GetNumGroups()
 		return false;
 	}
 
-	++numGroups_;                 // The indexes start at 0, we want the total #
+	// The first group has no start image number, set it to 1 for consistency
+
+	groupStartImage_[0] = 1;
+	
 	delete [] storage;
 	storage = NULL;
 	return true;
