@@ -1,4 +1,4 @@
-#define VERSION "2.30.0"
+#define VERSION "2.31.1"
 
 //****************************************************************************
 //
@@ -413,9 +413,8 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 		DICOMImage *dcmImg = new DICOMImage(dcmFile.c_str(), opts.verbose, (opts.numSlices > 0));
 		if (*dcmImg)
 		{
-			SeriesInfo si = seriesMap[dcmImg->SeriesID()];
-			
 			// If no entry for this list exists yet, create it
+			SeriesInfo si = seriesMap[dcmImg->SeriesID()];
 
 			int imgNum = dcmImg->ImageNumber();
 
@@ -581,15 +580,14 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 			}
 		}
 		
-		// For each series, check the number of groups (first image in first
-		// time point is sufficient)
+		// For each series, check the number of groups (first image in first time point is sufficient)
 
 		IMAGEMAP fullImageMap = si.imageMap;
 		IMAGEMAP::iterator fimIter = fullImageMap.begin();
 		IMAGELIST *firstTimePoint = fimIter->second;
 		DICOMImage firstImg = firstTimePoint->front();
 		const int numGroups = firstImg.NumGroups();
-		
+
 		// Try to guess if everything's allright with number of time points
 		if (opts.verbose)
 		{
@@ -661,10 +659,12 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 				IMAGELIST *timePoint = timeIter->second;
 				for (IMAGELIST::iterator img = timePoint->begin(); img != timePoint->end(); ++img)
 				{
-					// We know the acqisition number, figure out which group it
-					// belongs to.
+					// If we have info from Siemen's shadow set, use it, otherwise
+					// we know the acqisition number, figure out which group it belongs to.
 
-					int group = (img->ImageNumber() - si.minImgNum) / numImgGroup + 1;
+					int group = img->GroupNumber(img->ImageNumber()) + 1;
+					if ( (group == 1) && (img->GroupSize(0) == 0) )
+						group = (img->ImageNumber() - si.minImgNum) / numImgGroup + 1;
 					SeriesInfo newSeriesInfo = newSeriesMap[newSeriesNames[group]];
 					IMAGELIST *newTimePoint = newSeriesInfo.imageMap[acqNum];
 					if (newTimePoint == NULL)
@@ -674,8 +674,21 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 						newName << si.outName << "-" << group;
 						newSeriesInfo.outName = newName.str();
 						newSeriesInfo.mosaic = si.mosaic;
-						newSeriesInfo.minImgNum = (group - 1) * numImgGroup + si.minImgNum;
-						newSeriesInfo.maxImgNum = group * numImgGroup + si.minImgNum - 1;
+
+						// If we have Siemen's info from Siemen's showdow set, use it
+
+						if (img->GroupSize(0) > 0 )
+						{
+							newSeriesInfo.numSlices = img->GroupSize(group -1);
+							newSeriesInfo.minImgNum = img->GroupStartImage(group-1);
+							newSeriesInfo.maxImgNum = newSeriesInfo.minImgNum + newSeriesInfo.numSlices - 1;
+						}
+						else
+						{
+							newSeriesInfo.minImgNum = (group - 1) * numImgGroup + si.minImgNum;
+							newSeriesInfo.maxImgNum = group * numImgGroup + si.minImgNum - 1;
+						}
+						
 						newSeriesInfo.maxAcqNum = si.maxAcqNum;
 						newSeriesInfo.minAcqNum = si.minAcqNum;
 					}
